@@ -106,6 +106,16 @@ fn_jsonb_array_2_text_array: Final = (
     f" LANGUAGE SQL "
     f" IMMUTABLE;")
 
+fn_jsonb_2_jsonb_array: Final = (
+    f" CREATE OR REPLACE FUNCTION "
+    f" {CFn.fn_jsonb_2_jsonb_array} (JSONB) "
+    f" RETURNS JSONB[] "
+    f" AS $$ "
+    f"   SELECT array_agg(x)::JSONB[] || ARRAY[]::JSONB[] FROM {BFn.jsonb_array_elements}($1) t(x);"
+    f" $$ "
+    f" LANGUAGE SQL "
+    f" IMMUTABLE;")
+
 fn_jsonb_remove_key: Final = (
     f" CREATE OR REPLACE FUNCTION "
     f" {CFn.jsonb_remove_key} (JSONB, TEXT) "
@@ -158,6 +168,7 @@ def insert_util_fn__json(conn):
     cursor.execute(fn_jsonb_array_2_int_array)
     cursor.execute(fn_jsonb_array_2_smallint_array)
     cursor.execute(fn_jsonb_array_2_text_array)
+    cursor.execute(fn_jsonb_2_jsonb_array)
     cursor.execute(fn_jsonb_remove_key)
     cursor.execute(fn_count_jsonb_keys)
     # cursor.execute(fn_jsonb_add_key_value)
